*Rough Work in Progress at this point. Recommend 'watching' this repo if interested to monitor progress*

A CLI app for interacting with Aruba Central Clound Management Platform. The aim is to support a lot of the common work-flows via a simple CLI with auto-complete, help text etc.  Bulk tasks supported via import-files.

**Work in Progress pre-alpha**

Additional Documentation to follow.